/*
    DAAC_ConversionTask.h

    Copyright 2008,2009 Josh Freeman
    http://www.twilightedge.com

    This file is part of DAA Converter v1.3 for Mac OS X.

    DAA Converter is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#import <Cocoa/Cocoa.h>


@interface DAAC_ConversionTask : NSObject
{
    id _delegate;

    NSTask *_daa2isoTask;
    NSPipe *_daa2isoTaskOutputPipe;
    NSPipe *_daa2isoTaskInputPipe;

    NSString *_currentDAAFilename;
    NSString *_isoFilepath;

    unsigned _taskStatus;
    unsigned _conversionCompletionPercentage;

    bool _archiveHasUnknownDAAVersion;
}

+ conversionTaskWithSourceDAAFile: (NSString *) daaFilepath
                    targetISOFile: (NSString *) isoFilepath
                    delegate: (id) delegate;

- initWithSourceDAAFile: (NSString *) daaFilepath
        targetISOFile: (NSString *) isoFilepath
        delegate: (id) delegate;

- (void) cancel;

- (void) submitEncryptionPassword: (NSString *) password;

+ (NSString *) daa2isoCredits;

@end


@interface NSObject (DAAC_ConversionTaskDelegateMethods)

- (void) conversionTaskCompletedSuccessfully: (DAAC_ConversionTask *) conversionTask;

- (void) conversionTask: (DAAC_ConversionTask *) conversionTask
            failedOnDAAFile: (NSString *) daaFilename
            withErrorMessage: (NSString *) errorMessage;

- (void) conversionTask: (DAAC_ConversionTask *) conversionTask
            openedDAAFile: (NSString *) filename;

- (void) conversionTask: (DAAC_ConversionTask *) conversionTask
            didProgress: (unsigned) completionPercentage;

- (void) conversionTaskRequiresEncryptionPassword: (DAAC_ConversionTask *) conversionTask;

@end
